@@ -1,3 +1,22 @@
+/***************************************************************************
+ *   Copyright (C) 2007-2008 by Shawn Starr <shawn.starr@rogers.com>       *
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ *   This program is distributed in the hope that it will be useful,       *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
+ *   GNU General Public License for more details.                          *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the                         *
+ *   Free Software Foundation, Inc.,                                       *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA          *
+ ***************************************************************************/
+
 /*************************************************************************\
 *   Copyright (C) 2009 by Ulf Kreissig                                    *
 *   udev@gmx.net                                                          *
@@ -30,6 +49,7 @@
 //--- KDE4 ---
 #include <KDateTime>
 #include <KSystemTimeZones>
+#include <kdeversion.h>
 
 const QString GoogleIon::IonName("google");
 const QString GoogleIon::ActionValidate("validate");
@@ -79,6 +99,10 @@ struct GoogleIon::Private
 	QHash<KJob *, XmlServiceData *>     vJobData;
 	QHash<QString, KJob *>              vActiveJobs;
 	
+#if KDE_IS_VERSION(4,5,2)
+	QStringList                         sourcesToReset;
+#endif
+	
 	QString getNodeValue( const QXmlStreamReader & xml ) const;
 	QString createLocationString( const QString & sCityTag, const QString & sPostalTag ) const;
 	
@@ -90,7 +114,6 @@ struct GoogleIon::Private
 	{
 		return (sValue.isEmpty() || sValue.compare("NA")==0)? "N/A" : sValue;
 	}
-
 };
 
 GoogleIon::GoogleIon( QObject * parent, const QVariantList & args )
@@ -207,9 +230,12 @@ GoogleIon::reset()
 	d->vJobData.clear();
 	d->vActiveJobs.clear();
 
-#if KDE_VERSION_MINOR >= 3
 	/**  Triggered when we get initial setup data for ions that provide a list of places */
-    emit(resetCompleted(this, true));
+#if KDE_IS_VERSION(4,5,2)
+	d->sourcesToReset = sources();
+	updateAllSources();
+#elif KDE_VERSION_MINOR >= 3
+	emit(resetCompleted(this, true));
 #endif
 }
 
